Model selection via AIC or BIC criteria. For Lasso estimators, the degree of freedom is the number of distinct groups of estimated abilities.
BTdecayLassoC(
dataframe,
ability,
weight = NULL,
criteria = "AIC",
type = "HYBRID",
model = NULL,
decay.rate = 0,
fixed = 1,
thersh = 1e-05,
iter = 100,
max = 100
)Lowest AIC or BIC score
The degree of freedom where lowest AIC or BIC score is achieved
The ability where lowest AIC or BIC score is achieved
Matrix contains all abilities computed in this algorithm
The lambda where lowest score is attained
The penalty (1- s/\(\max(s)\)) where lowest score is attained
Type of model selection method
Decay rate of this model
Generated using BTdataframe given raw data.
A column vector of teams ability, the last row is the home parameter.
The row number is consistent with the team's index shown in dataframe. It can be generated using BTdataframe given raw data.
Weight for Lasso penalty on different abilities
"AIC" or "BIC"
"HYBRID" or "LASSO"
An Lasso path object with class wlasso or swlasso. If NULL, the whole lasso path will be run.
The exponential decay rate. Usually ranging from (0, 0.01), A larger decay rate weights more importance to most recent matches and the estimated parameters reflect more on recent behaviour.
A teams index whose ability will be fixed as 0. The worstTeam's index
can be generated using BTdataframe given raw data.
Threshold for convergence
Number of iterations used in L-BFGS-B algorithm.
Maximum weight for \(w_{ij}\) (weight used for Adaptive Lasso)
This function is usually run after the run of whole Lasso path. "model" parameter is obtained by whole
Lasso pass's run using BTdecayLasso. If no model is provided, this function will run Lasso path first (time-consuming).
Users can select the information score added to HYBRID Lasso's likelihood or original Lasso's likelihood. ("HYBRID" is recommended)
summary() function can be applied to view the outputs.
Masarotto, G. and Varin, C.(2012) The Ranking Lasso and its Application to Sport Tournaments. *The Annals of Applied Statistics* **6** 1949--1970.
Zou, H. (2006) The adaptive lasso and its oracle properties. *J.Amer.Statist.Assoc* **101** 1418--1429.
BTdataframe for dataframe initialization,
BTdecayLasso for obtaining a whole Lasso path